@@ -4,7 +4,6 @@
 # for performance reasons, so turn off the lint warning
 # pylint: disable=import-outside-toplevel
 
-import logging
 import os
 import sys
 from typing import Optional
@@ -16,6 +15,7 @@ from autoupgrade import Package
 
 from suite_py.__version__ import __version__
 from suite_py.lib import logger
+from suite_py.lib import metrics
 from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
@@ -99,11 +99,14 @@ def upgrade_suite_py_if_needed(break_on_missing_package: bool = False) -> None:
 @click.option("-v", "--verbose", count=True)
 @click.pass_context
 def main(ctx, project, timeout, verbose):
+    config = Config()
+
+    logger.setup(verbose)
+    metrics.setup(config)
+
+    logger.debug(f"v{__version__}")
     maybe_inject_truststore()
     upgrade_suite_py_if_needed(break_on_missing_package=False)
-    print(f"v{__version__}")
-
-    config = Config()
 
     if ctx.invoked_subcommand not in ALLOW_NO_GIT_SUBCOMMAND:
         project = git.get_root_folder(project)
@@ -135,10 +138,6 @@ def main(ctx, project, timeout, verbose):
     ):
         sys.exit()
 
-    if verbose:
-        logger.setLevel(logging.DEBUG)
-        logger.debug("Logging as 'DEBUG'")
-
     ctx.ensure_object(dict)
     ctx.obj["project"] = os.path.basename(project)
     if timeout:
@@ -154,6 +153,12 @@ def main(ctx, project, timeout, verbose):
         os.chdir(os.path.join(config.user["projects_home"], ctx.obj["project"]))
 
 
+@main.result_callback()
+@click.pass_obj
+def cleanup(_obj, _, **_kwargs):
+    metrics.async_upload()
+
+
 @main.command("bump", help="Bumps the project version based on the .versions.yml file")
 @click.option("--project", required=False, type=str)
 @click.option(
