@@ -2,6 +2,7 @@
 import sys
 
 from suite_py.lib import logger
+from suite_py.lib import metrics
 from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.handler.frequent_reviewers_handler import FrequentReviewersHandler
 from suite_py.lib.handler.git_handler import GitHandler
@@ -20,7 +21,9 @@ class AskReview:
         self._github = GithubHandler(tokens)
         self._frequent_reviewers = FrequentReviewersHandler(config)
 
+    @metrics.command("ask-review")
     def run(self):
+
         users = self._maybe_get_users_list()
         pr = self._get_pr()
         youtrack_reviewers = self._ask_reviewer(users)
