@@ -5,6 +5,7 @@ import sys
 from suite_py.commands import common
 from suite_py.commands.release import _parse_available_countries
 from suite_py.lib import logger
+from suite_py.lib import metrics
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.captainhook_handler import CaptainHook
@@ -31,6 +32,7 @@ class Deploy:
         self._countries = _parse_available_countries(self._drone)
         self._version = VersionHandler(self._repo, self._git, self._github)
 
+    @metrics.command("deploy")
     def run(self):
         self._stop_if_prod_locked()
 
