@@ -4,6 +4,7 @@ import sys
 from halo import Halo
 
 from suite_py.lib import logger
+from suite_py.lib import metrics
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.captainhook_handler import CaptainHook
@@ -24,6 +25,7 @@ class MergePR:
         self._github = GithubHandler(tokens)
         self._drone = DroneHandler(config, tokens, repo=project)
 
+    @metrics.command("merge-pr")
     def run(self):
         # pylint: disable=too-many-branches
         self._stop_if_master_locked()
@@ -53,15 +55,14 @@ class MergePR:
             logger.error("An error occurred during the merge.")
             sys.exit(-1)
 
-        drone_build_number = self._drone.get_pr_build_number(merge_status.sha)
-        drone_build_url = self._drone.get_build_url(drone_build_number)
+        logger.info("Pull request merged on master!")
 
-        if drone_build_url:
-            logger.info(
-                f"Pull request merged on master! You can follow the build status at {drone_build_url}"
-            )
-        else:
-            logger.info("Pull request merged on master!")
+        if self._drone.parse_yaml():
+            drone_build_number = self._drone.get_pr_build_number(merge_status.sha)
+            drone_build_url = self._drone.get_build_url(drone_build_number)
+
+            if drone_build_url:
+                logger.info(f"You can follow the build status at {drone_build_url}")
 
         self._git.fetch()
         if self._git.remote_branch_exists(branch_name):
