@@ -12,6 +12,7 @@ from rich.table import Table
 
 from suite_py.commands.login import Login
 from suite_py.lib import logger
+from suite_py.lib import metrics
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.drone_handler import DroneHandler
@@ -32,6 +33,7 @@ class QA:
         self._youtrack = YoutrackHandler(config, tokens)
         self._drone = DroneHandler(config, tokens)
 
+    @metrics.command("qa")
     def run(self):
         if not self._qainit.user_info():
             logger.warning("You're not logged in.")
@@ -96,15 +98,21 @@ class QA:
             qa["name"],
             qa["hash"],
             qa["card"],
-            qa.get("created", {}).get("github_username", "/")
-            if qa["created"] is not None
-            else "/",
-            qa.get("updated", {}).get("github_username", "/")
-            if qa["updated"] is not None
-            else "/",
-            qa.get("deleted", {}).get("github_username", "/")
-            if qa["deleted"] is not None
-            else "/",
+            (
+                qa.get("created", {}).get("github_username", "/")
+                if qa["created"] is not None
+                else "/"
+            ),
+            (
+                qa.get("updated", {}).get("github_username", "/")
+                if qa["updated"] is not None
+                else "/"
+            ),
+            (
+                qa.get("deleted", {}).get("github_username", "/")
+                if qa["deleted"] is not None
+                else "/"
+            ),
             self._clean_date(qa["updated_at"]),
             qa["status"],
         )
@@ -211,9 +219,11 @@ class QA:
                         table.add_row(
                             resource["name"],
                             drone_url,
-                            resource["ref"]
-                            if resource["ref"] == "master"
-                            else f"[green]{resource['ref']}[/green]",
+                            (
+                                resource["ref"]
+                                if resource["ref"] == "master"
+                                else f"[green]{resource['ref']}[/green]"
+                            ),
                             self._clean_date(resource["updated_at"]),
                             resource["status"],
                         )
