@@ -1,6 +1,7 @@
 import sys
 
 from suite_py.lib import logger
+from suite_py.lib import metrics
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.tokens import Tokens
 
@@ -9,6 +10,7 @@ class SetToken:
     def __init__(self, tokens: Tokens):
         self._tokens = tokens
 
+    @metrics.command("set-token")
     def run(self):
         selected = self._select_token()
         if not selected or selected.lower() != selected or selected.strip() != selected:
